==> kpeople_5.31.0.orig.tar.xz: kpeople-5.31.0/src/widgets/persondetailsview.h <==
/*
    Copyright (C) 2011  Martin Klapetek <mklapetek@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef PERSON_DETAILS_VIEW_H
#define PERSON_DETAILS_VIEW_H

#include <QWidget>
#include <QVariantList>

#include <kpeople/kpeople_export.h>

#include "../persondata.h"

class QLabel;
class QVBoxLayout;

namespace KPeople
{
class PersonDetailsViewPrivate;

/**
 * Use PersonDetailsView to integrate a person's information
 * in the GUI.
 */
class KPEOPLE_EXPORT PersonDetailsView : public QWidget
{
    Q_OBJECT
public:
    PersonDetailsView(QWidget *parent = nullptr);
    virtual ~PersonDetailsView();

public Q_SLOTS:
    /** Specifies the @p person for which the details will be displayed. */
    void setPerson(PersonData *person);
//     void setPersonsModel(PersonsModel *model);

private Q_SLOTS:
    void reload();

private:
    Q_DECLARE_PRIVATE(PersonDetailsView)
    PersonDetailsViewPrivate *d_ptr;
};
}

#endif // PERSON_DETAILS_VIEW_H

==> kpeople_5.68.0.orig.tar.xz: kpeople-5.68.0/src/widgets/persondetailsview.h <==
/*
    Copyright (C) 2011  Martin Klapetek <mklapetek@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef PERSON_DETAILS_VIEW_H
#define PERSON_DETAILS_VIEW_H

#include <QWidget>

#include <kpeople/widgets/kpeoplewidgets_export.h>

#include "../persondata.h"

class QLabel;
class QVBoxLayout;

namespace KPeople
{
class PersonDetailsViewPrivate;

/**
 * Use PersonDetailsView to integrate a person's information
 * in the GUI.
 *
 * @since 5.8
 */
class KPEOPLEWIDGETS_EXPORT PersonDetailsView : public QWidget
{
    Q_OBJECT
public:
    PersonDetailsView(QWidget *parent = nullptr);
    virtual ~PersonDetailsView();

public Q_SLOTS:
    /** Specifies the @p person for which the details will be displayed. */
    void setPerson(PersonData *person);
//     void setPersonsModel(PersonsModel *model);

private Q_SLOTS:
    void reload();

private:
    Q_DECLARE_PRIVATE(PersonDetailsView)
    PersonDetailsViewPrivate *d_ptr;
};
}

#endif // PERSON_DETAILS_VIEW_H
